/// <reference types="react" />
import ApolloClient from 'apollo-client';
export declare type IApolloClients = {
    [name: string]: ApolloClient<any>;
};
export declare type IExtractedData = {
    [name: string]: any;
};
/**
 * React context to hold ApolloClientsManager instance
 */
export declare const ApolloClientsContext: import("react").Context<ApolloClientsManager>;
/**
 * Used as the IoC container to inject Apollo client instances into components
 * based on their names
 */
export declare class ApolloClientsManager {
    clients: IApolloClients;
    constructor(clients: IApolloClients);
    getClient(key?: string): ApolloClient<any>;
    extract(): IExtractedData;
}
/**
 * Injects Apollo client from the context based on the provided name or
 * uses the provided instance. If called without arguments, uses the default
 * instance
 *
 * @param clientOrName - name of the Apollo client to be injected, or instance to be used
 */
export declare function useContextApolloClient(clientOrName: string | ApolloClient<any>): ApolloClient<any>;
