import { DependencyList } from 'react';
import { PartialKey } from '@proscom/prostore';
import { IGraphqlWatchQueryOptions, IGraphqlWatchQueryStoreParams } from '@proscom/prostore-apollo';
import { ApolloClient } from 'apollo-client';
export declare type IUseGraphqlWatchQueryOptions<Vars, Data> = PartialKey<IGraphqlWatchQueryStoreParams<Vars, Data>, 'client'>;
export interface IUseGraphqlWatchQueryParams<Vars, Data> {
    /** Apollo Client instance to be used for data fetching, or its name for it to be injected from the context */
    client?: string | ApolloClient<any>;
    /** Query specification */
    queryOptions?: IUseGraphqlWatchQueryOptions<Vars, Data>;
    /** Query variables */
    variables?: Vars;
    /** Additional query options */
    options?: IGraphqlWatchQueryOptions<Vars, Data>;
}
/**
 * Creates GraphqlWatchQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the apollo based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useGraphqlWatchQuery<Vars, Data>({ client, queryOptions, variables, options }: IUseGraphqlWatchQueryParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<import("@proscom/prostore").IRequestState<Vars, Data>>;
export interface IUseGraphWatchQueryVarsParams<Vars, Data> extends IUseGraphqlWatchQueryParams<Vars, Data> {
    variableCreator: [() => Vars, DependencyList];
}
/**
 * The same as useGraphqlWatchQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useGraphqlWatchQueryVars<Vars, Data>({ variableCreator, ...queryProps }: IUseGraphWatchQueryVarsParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<import("@proscom/prostore").IRequestState<Vars, Data>>;
