"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGraphqlWatchQueryVars = exports.useGraphqlWatchQuery = void 0;
var react_1 = require("react");
var prostore_apollo_1 = require("@proscom/prostore-apollo");
var prostore_react_1 = require("@proscom/prostore-react");
var ApolloClientsContext_1 = require("./ApolloClientsContext");
/**
 * Creates GraphqlWatchQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the apollo based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
function useGraphqlWatchQuery(_a) {
    var client = _a.client, queryOptions = _a.queryOptions, variables = _a.variables, options = _a.options;
    var actualClient = ApolloClientsContext_1.useContextApolloClient(client);
    var ssrContext = react_1.useContext(prostore_react_1.ProstoreSsrContext);
    var store = react_1.useMemo(function () {
        return new prostore_apollo_1.GraphqlWatchQueryStore(__assign({ ssrContext: ssrContext, client: actualClient }, queryOptions));
    }, [ssrContext, actualClient, queryOptions]);
    return prostore_react_1.useRequestStore(store, variables, options);
}
exports.useGraphqlWatchQuery = useGraphqlWatchQuery;
/**
 * The same as useGraphqlWatchQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 */
function useGraphqlWatchQueryVars(_a) {
    var variableCreator = _a.variableCreator, queryProps = __rest(_a, ["variableCreator"]);
    var variables = react_1.useMemo.apply(void 0, variableCreator);
    return useGraphqlWatchQuery(__assign(__assign({}, queryProps), { variables: variables }));
}
exports.useGraphqlWatchQueryVars = useGraphqlWatchQueryVars;
//# sourceMappingURL=useGraphqlWatchQuery.js.map